PixelEndian

Enum PixelEndian 

pub enum PixelEndian {
    Big,
    Little,
}
Describes the endianness of pixel data in SER frames

Developers Note

Astonishingly, by convention most SER implementations invert this flag’s value from the official specification.

For example, Siril’s source code contains the following comment:

“For an unknown reason, several of the first programs to support SER disrespect the specification regarding the endianness flag. The specification states that a boolean value is used for the LittleEndian header, and they use it as a BigEndian header, with 0 for little-endian and 1 for big-endian. Consequently, to not break compatibility with these first implementations, later programs, like Siril and GoQat, have also decided to implement this header in opposite meaning to the specification.”

Other rust crates seem to follow this convention, and this crate does as well.

Variants



Big



Little