pub struct FrameFormat { /* private fields */ }Expand description
The format defining all images in a SER file.
Only one format per SER file is supported. All images must have the same width, height, bytes per pixel, etc.
Once a format is defined, SER frames may be converted to/from image::DynamicImages. Furthermore, a FrameFormat may be computed from an existing DynamicImage using TryFrom.
Implementations
Sourceimpl FrameFormat
impl FrameFormat
Sourceimpl FrameFormat
impl FrameFormat
pub fn set_color(&mut self, val: ColorId) -> &mut Self
pub fn set_depth(&mut self, val: PixelDepth) -> &mut Self
pub fn set_endian(&mut self, val: PixelEndian) -> &mut Self
pub fn set_width(&mut self, val: u32) -> &mut Self
pub fn set_height(&mut self, val: u32) -> &mut Self
Sourceimpl FrameFormat
impl FrameFormat
pub fn new( color: ColorId, depth: PixelDepth, endian: PixelEndian, width: u32, height: u32, ) -> Self
pub fn raw_len(&self) -> usize
Sourcepub fn try_into_frame(&self, img: DynamicImage) -> Result<Frame, &'static str>
pub fn try_into_frame(&self, img: DynamicImage) -> Result<Frame, &'static str>
Attempt to convert a DynamicImage into a Frame that is compatible with this FrameFormat.