Ser

Struct Ser 

pub struct Ser { /* private fields */ }
SER format description version 3

Authors Heiko Wilkens (version 2) Grischa Hahn (red = extensions of version 3)

2014 Feb 06

Source: https://grischa-hahn.hier-im-netz.de/astro/ser/SER%20Doc%20V3b.pdf

Implementations

Source

impl Ser

pub fn lu_id(&self) -> &i32

2_LuID

Format: Integer_32 (little-endian)

Length: 4 Byte

Content: Lumenera camera series ID (currently unused; default = 0)

pub fn observer(&self) -> &FixedString<40>

9_Observer

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of observer

pub fn instrument(&self) -> &FixedString<40>

10_Instrument

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of used camera

pub fn telescope(&self) -> &FixedString<40>

11_Telescope

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of used telescope

pub fn datetime(&self) -> &Timestamp

12_DateTime

Format: Date / Integer_64 (little-endian)

Length: 8 Byte

Content: Start time of image stream (local time)

If 12_DateTime <= 0 then 12_DateTime is invalid and the SER file does not contain a Time stamp trailer.

pub fn datetime_utc(&self) -> &Timestamp

13_DateTime_UTC

Format: Date / Integer_64 (little-endian)

Length: 8 Byte

Content: Start time of image stream in UTC

Source

impl Ser

pub fn set_lu_id(&mut self, val: i32) -> &mut Self

2_LuID

Format: Integer_32 (little-endian)

Length: 4 Byte

Content: Lumenera camera series ID (currently unused; default = 0)

pub fn set_observer(&mut self, val: FixedString<40>) -> &mut Self

9_Observer

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of observer

pub fn set_instrument(&mut self, val: FixedString<40>) -> &mut Self

10_Instrument

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of used camera

pub fn set_telescope(&mut self, val: FixedString<40>) -> &mut Self

11_Telescope

Format: String

Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)

Content: Name of used telescope

Source

impl Ser

pub fn with_format(format: FrameFormat) -> Self

pub fn frame_format(&self) -> FrameFormat

Creates a new copy of this SER’s frame format

pub fn has_frame_timestamps(&self) -> bool

SER files include timestamps for each frame only if the datetime field is valid.

pub fn frame_count(&self) -> usize

The number of frames

pub fn iter(&self) -> impl Iterator<Item = (&Frame, Option<&Timestamp>)>

Returns an iterator for Frame references and their associated Timestamp if provided.

pub fn into_iter(self) -> impl Iterator<Item = (Frame, Option<Timestamp>)>

Moves into an iterator for Frames and their associated Timestamp if provided.

pub fn frames_mut<'a>(&'a mut self) -> FramesMut<'a>

Returns a FramesMut object for mutating frames

pub fn dates_mut<'a>(&'a mut self) -> DatesMut<'a>

Returns a DatesMut object for mutating dates and frame timestamps