pub struct Ser { /* private fields */ }Expand description
SER format description version 3
Authors Heiko Wilkens (version 2) Grischa Hahn (red = extensions of version 3)
2014 Feb 06
Source: https://grischa-hahn.hier-im-netz.de/astro/ser/SER%20Doc%20V3b.pdf
Implementations
Sourceimpl Ser
impl Ser
Sourcepub fn lu_id(&self) -> &i32
pub fn lu_id(&self) -> &i32
2_LuID
Format: Integer_32 (little-endian)
Length: 4 Byte
Content: Lumenera camera series ID (currently unused; default = 0)
Sourcepub fn observer(&self) -> &FixedString<40>
pub fn observer(&self) -> &FixedString<40>
9_Observer
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of observer
Sourcepub fn instrument(&self) -> &FixedString<40>
pub fn instrument(&self) -> &FixedString<40>
10_Instrument
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of used camera
Sourcepub fn telescope(&self) -> &FixedString<40>
pub fn telescope(&self) -> &FixedString<40>
11_Telescope
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of used telescope
Sourcepub fn datetime(&self) -> &Timestamp
pub fn datetime(&self) -> &Timestamp
12_DateTime
Format: Date / Integer_64 (little-endian)
Length: 8 Byte
Content: Start time of image stream (local time)
If 12_DateTime <= 0 then 12_DateTime is invalid and the SER file does not contain a Time stamp trailer.
Sourcepub fn datetime_utc(&self) -> &Timestamp
pub fn datetime_utc(&self) -> &Timestamp
13_DateTime_UTC
Format: Date / Integer_64 (little-endian)
Length: 8 Byte
Content: Start time of image stream in UTC
Sourceimpl Ser
impl Ser
Sourcepub fn set_lu_id(&mut self, val: i32) -> &mut Self
pub fn set_lu_id(&mut self, val: i32) -> &mut Self
2_LuID
Format: Integer_32 (little-endian)
Length: 4 Byte
Content: Lumenera camera series ID (currently unused; default = 0)
Sourcepub fn set_observer(&mut self, val: FixedString<40>) -> &mut Self
pub fn set_observer(&mut self, val: FixedString<40>) -> &mut Self
9_Observer
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of observer
Sourcepub fn set_instrument(&mut self, val: FixedString<40>) -> &mut Self
pub fn set_instrument(&mut self, val: FixedString<40>) -> &mut Self
10_Instrument
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of used camera
Sourcepub fn set_telescope(&mut self, val: FixedString<40>) -> &mut Self
pub fn set_telescope(&mut self, val: FixedString<40>) -> &mut Self
11_Telescope
Format: String
Length: 40 Byte (40 ASCII characters {32…126 dec.}, fill unused characters with 0 dec.)
Content: Name of used telescope
Sourceimpl Ser
impl Ser
pub fn with_format(format: FrameFormat) -> Self
Sourcepub fn frame_format(&self) -> FrameFormat
pub fn frame_format(&self) -> FrameFormat
Creates a new copy of this SER’s frame format
Sourcepub fn has_frame_timestamps(&self) -> bool
pub fn has_frame_timestamps(&self) -> bool
SER files include timestamps for each frame only if the datetime field
is valid.
Sourcepub fn frame_count(&self) -> usize
pub fn frame_count(&self) -> usize
The number of frames
Sourcepub fn frames_mut<'a>(&'a mut self) -> FramesMut<'a>
pub fn frames_mut<'a>(&'a mut self) -> FramesMut<'a>
Returns a FramesMut object for mutating frames